@@ -1,7 +1,7 @@
 /*
  * MIT License
  *
- * Copyright (c) 2002-2021 Mikko Tommila
+ * Copyright (c) 2002-2023 Mikko Tommila
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -94,6 +94,6 @@ public class LongAparapiFactor3NTTStrategy
 
         LongKernel kernel = LongKernel.getInstance();
         kernel.get(arrayAccess.getLongData());
-        //kernel.cleanUpArrays(); // FIXME needs to be fixed in aparapi
+        kernel.cleanUpArrays();
     }
 }
