@@ -24,6 +24,7 @@
 package org.apfloat.calc;
 
 import java.math.RoundingMode;
+import java.util.function.BiFunction;
 
 import org.apfloat.Apcomplex;
 import org.apfloat.ApcomplexMath;
@@ -39,7 +40,7 @@ import org.apfloat.spi.Util;
 /**
  * Arbitrary precision calculator implementation.
  *
- * @version 1.13.0
+ * @version 1.14.0
  * @author Mikko Tommila
  */
 
@@ -210,6 +211,17 @@ public class ApfloatCalculatorImpl
             return AprationalMath.bernoulli(n);
         }
 
+        @Override
+        public Number bernoulliB(Number x, Number y)
+        {
+            if (!isLong(x))
+            {
+                throw new IllegalArgumentException("Bernoulli B can only be used with a valid integer first argument");
+            }
+            long n = x.longValue();
+            return fixedOrArbitraryPrecision(fixedPrecisionApcomplexHelper::bernoulliB, ApcomplexMath::bernoulliB, n, (Apcomplex) y);
+        }
+
         @Override
         public Number besselI(Number x, Number y)
         {
@@ -281,6 +293,18 @@ public class ApfloatCalculatorImpl
             throw new IllegalArgumentException("Ceiling can only be used with scalar values");
         }
 
+        @Override
+        public Number chebyshevT(Number x, Number y)
+        {
+            return ApcomplexMath.chebyshevT((Apcomplex) x, (Apcomplex) y);
+        }
+
+        @Override
+        public Number chebyshevU(Number x, Number y)
+        {
+            return ApcomplexMath.chebyshevU((Apcomplex) x, (Apcomplex) y);
+        }
+
         @Override
         public Number cos(Number x)
         {
@@ -311,6 +335,17 @@ public class ApfloatCalculatorImpl
             return ApcomplexMath.digamma((Apcomplex) x);
         }
 
+        @Override
+        public Number doubleFactorial(Number x)
+        {
+            if (!isLong(x))
+            {
+                throw new IllegalArgumentException("Double factorial can only be used with a valid integer argument");
+            }
+            long n = x.longValue();
+            return ApintMath.doubleFactorial(n);
+        }
+
         @Override
         public Number e(Number x)
         {
@@ -363,6 +398,17 @@ public class ApfloatCalculatorImpl
             return ApfloatMath.euler(n);
         }
 
+        @Override
+        public Number eulerE(Number x, Number y)
+        {
+            if (!isLong(x))
+            {
+                throw new IllegalArgumentException("Euler E can only be used with a valid integer first argument");
+            }
+            long n = x.longValue();
+            return fixedOrArbitraryPrecision(fixedPrecisionApcomplexHelper::eulerE, ApcomplexMath::eulerE, n, (Apcomplex) y);
+        }
+
         @Override
         public Number exp(Number x)
         {
@@ -392,6 +438,12 @@ public class ApfloatCalculatorImpl
             return ApintMath.factorial(n);
         }
 
+        @Override
+        public Number fibonacci(Number x, Number y)
+        {
+            return ApcomplexMath.fibonacci((Apcomplex) x, (Apcomplex) y);
+        }
+
         @Override
         public Number floor(Number x)
         {
@@ -416,6 +468,18 @@ public class ApfloatCalculatorImpl
             return ApcomplexMath.fresnelS((Apcomplex) x);
         }
 
+        @Override
+        public Number gegenbauerC(Number x, Number y)
+        {
+            return ApcomplexMath.gegenbauerC((Apcomplex) x, (Apcomplex) y);
+        }
+
+        @Override
+        public Number gegenbauerC(Number x, Number y, Number z)
+        {
+            return ApcomplexMath.gegenbauerC((Apcomplex) x, (Apcomplex) y, (Apcomplex) z);
+        }
+
         @Override
         public Number glaisher(Number x)
         {
@@ -445,6 +509,24 @@ public class ApfloatCalculatorImpl
             return ApcomplexMath.gamma((Apcomplex) x, (Apcomplex) y, (Apcomplex) z);
         }
 
+        @Override
+        public Number harmonicNumber(Number x)
+        {
+            return ApcomplexMath.harmonicNumber((Apcomplex) x);
+        }
+
+        @Override
+        public Number harmonicNumber(Number x, Number y)
+        {
+            return ApcomplexMath.harmonicNumber((Apcomplex) x, (Apcomplex) y);
+        }
+
+        @Override
+        public Number hermiteH(Number x, Number y)
+        {
+            return ApcomplexMath.hermiteH((Apcomplex) x, (Apcomplex) y);
+        }
+
         @Override
         public Number hypergeometric0F1(Number a, Number z)
         {
@@ -499,6 +581,12 @@ public class ApfloatCalculatorImpl
             throw new IllegalArgumentException("Inverse erfc can only be used with scalar values");
         }
 
+        @Override
+        public Number jacobiP(Number x, Number y, Number z, Number w)
+        {
+            return ApcomplexMath.jacobiP((Apcomplex) x, (Apcomplex) y, (Apcomplex) z, (Apcomplex) w);
+        }
+
         @Override
         public Number khinchin(Number x)
         {
@@ -510,6 +598,42 @@ public class ApfloatCalculatorImpl
             return ApfloatMath.khinchin(n);
         }
 
+        @Override
+        public Number laguerreL(Number x, Number y)
+        {
+            return ApcomplexMath.laguerreL((Apcomplex) x, (Apcomplex) y);
+        }
+
+        @Override
+        public Number laguerreL(Number x, Number y, Number z)
+        {
+            return ApcomplexMath.laguerreL((Apcomplex) x, (Apcomplex) y, (Apcomplex) z);
+        }
+
+        @Override
+        public Number legendreP(Number x, Number y)
+        {
+            return ApcomplexMath.legendreP((Apcomplex) x, (Apcomplex) y);
+        }
+
+        @Override
+        public Number legendreP(Number x, Number y, Number z)
+        {
+            return ApcomplexMath.legendreP((Apcomplex) x, (Apcomplex) y, (Apcomplex) z);
+        }
+
+        @Override
+        public Number legendreQ(Number x, Number y)
+        {
+            return ApcomplexMath.legendreQ((Apcomplex) x, (Apcomplex) y);
+        }
+
+        @Override
+        public Number legendreQ(Number x, Number y, Number z)
+        {
+            return ApcomplexMath.legendreQ((Apcomplex) x, (Apcomplex) y, (Apcomplex) z);
+        }
+
         @Override
         public Number log(Number x)
         {
@@ -534,6 +658,12 @@ public class ApfloatCalculatorImpl
             return ApcomplexMath.logIntegral((Apcomplex) x);
         }
 
+        @Override
+        public Number logisticSigmoid(Number x)
+        {
+            return ApcomplexMath.logisticSigmoid((Apcomplex) x);
+        }
+
         @Override
         public Number max(Number x, Number y)
         {
@@ -592,6 +722,12 @@ public class ApfloatCalculatorImpl
             return ApcomplexMath.polygamma(n, (Apcomplex) y);
         }
 
+        @Override
+        public Number polylog(Number x, Number y)
+        {
+            return ApcomplexMath.polylog((Apcomplex) x, (Apcomplex) y);
+        }
+
         @Override
         public Number random(Number x)
         {
@@ -650,6 +786,12 @@ public class ApfloatCalculatorImpl
             return ApcomplexMath.sin((Apcomplex) x);
         }
 
+        @Override
+        public Number sinc(Number x)
+        {
+            return ApcomplexMath.sinc((Apcomplex) x);
+        }
+
         @Override
         public Number sinIntegral(Number x)
         {
@@ -668,6 +810,12 @@ public class ApfloatCalculatorImpl
             return ApcomplexMath.sinhIntegral((Apcomplex) x);
         }
 
+        @Override
+        public Number sphericalHarmonicY(Number x, Number y, Number z, Number w)
+        {
+            return ApcomplexMath.sphericalHarmonicY((Apcomplex) x, (Apcomplex) y, (Apcomplex) z, (Apcomplex) w);
+        }
+
         @Override
         public Number sqrt(Number x)
         {
@@ -1157,6 +1305,18 @@ public class ApfloatCalculatorImpl
             return ApintMath.gcd((Apint) x, (Apint) y);
         }
 
+        @Override
+        public Number harmonicNumber(Number x)
+        {
+            return AprationalMath.harmonicNumber((Apint) x);
+        }
+
+        @Override
+        public Number harmonicNumber(Number x, Number y)
+        {
+            return AprationalMath.harmonicNumber((Apint) x, (Apint) y);
+        }
+
         @Override
         public Number lcm(Number x, Number y)
         {
@@ -1308,5 +1468,10 @@ public class ApfloatCalculatorImpl
         return (getInputPrecision() != null && z.isZero() ? fixedPrecisionFunction.apply(z) : arbitraryPrecisionFunction.apply(z));
     }
 
+    private <T extends Number, U extends Apcomplex> Number fixedOrArbitraryPrecision(BiFunction<T, U, Apcomplex> fixedPrecisionFunction, BiFunction<T, U, Apcomplex> arbitraryPrecisionFunction, T x, U y)
+    {
+        return (getInputPrecision() != null && y.isZero() ? fixedPrecisionFunction.apply(x, y) : arbitraryPrecisionFunction.apply(x, y));
+    }
+
     private FixedPrecisionApcomplexHelper fixedPrecisionApcomplexHelper = new FixedPrecisionApcomplexHelper(Apfloat.INFINITE);
 }
