@@ -32,7 +32,7 @@ import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
 /**
- * @version 1.11.0
+ * @version 1.14.0
  * @author Mikko Tommila
  */
 
@@ -167,6 +167,20 @@ public class CalculatorTest
         assertCalculation("8.8080652584e646456992", "2^2147483647.0");
         assertCalculation("-1", "i^2");
         assertCalculation("1", "1^2i");
+        assertCalculation("2417851639229258349412352", "2^3^4");
+        assertCalculation("120", "5!");
+        assertCalculation("15", "5!!");
+        assertCalculation("64", "2^3!");
+        assertCalculation("8", "2^3!!");
+        assertCalculation("1307674368000", "5!!!");
+        assertCalculation("2027025", "5!!!!");
+        assertCalculation("-24", "-4!");
+        assertCalculation("1/16777216", "2^-4!");
+        assertCalculation("-1/16777216", "-2^-4!");
+        assertCalculation("8", "2^3!!!!");
+        assertCalculation("-1/8", "-2^-3!!!!");
+        assertCalculation("4", "2!^2!");
+        assertCalculation("4", "2!!^2!!");
 
         assertCalculationFailure("6%i");
         assertCalculationFailure("5e");
@@ -184,6 +198,11 @@ public class CalculatorTest
         assertCalculationFailure("6%");
         assertCalculationFailure("2-");
         assertCalculationFailure("bogus^5");
+        assertCalculationFailure("!");
+        assertCalculationFailure("bogus!");
+        assertCalculationFailure("bogus!!");
+        assertCalculationFailure("5!=");
+        assertCalculationFailure("5!=4");
     }
 
     public static void testFunctions()
@@ -197,6 +216,7 @@ public class CalculatorTest
         assertCalculation("7.05464e-1", "airyBi(0.200000)");
         assertCalculation("4.61789e-1", "airyBiPrime(0.200000)");
         assertCalculation("7/6", "bernoulli(14)");
+        assertCalculation("3.3124e4", "bernoulliB(4,14.0000)");
         assertCalculation("1.72763", "besselI(0.700000,1.90000)");
         assertCalculation("5.84978e-1", "besselJ(0.700000,1.90000)");
         assertCalculation("2.06052", "besselK(0.700000,0.300000)");
@@ -204,7 +224,7 @@ public class CalculatorTest
         assertCalculation("3.55114", "beta(0.200000,4.00000)");
         assertCalculation("3.00545", "beta(0.100000,0.200000,4.00000)");
         assertCalculation("-1.02994", "beta(0.100000,2.90000,0.200000,4.00000)");
-        assertCalculation("1.5057e2", "binomial(9.2000,4.6000)");
+        assertCalculation("1.5057e2", "binomial(9.20000,4.60000)");
         assertCalculation("2.3282", "binomial(4,3.5000)");
         assertCalculation("6.5625", "binomial(4.5000,3)");
         assertCalculation("45", "binomial(10,2)");
@@ -224,18 +244,23 @@ public class CalculatorTest
         assertCalculation("1.2599", "cbrt(2.0000)");
         assertCalculation("2", "ceil(1.1)");
         assertCalculation("2", "ceil(3/2)");
+        assertCalculation("1.41288", "chebyshevT(0.70000,1.9000)");
+        assertCalculation("2.58673", "chebyshevU(0.700000,1.90000)");
         assertCalculation("-2", "copySign(2, -3)");
         assertCalculation("-1.04221", "cosIntegral(0.200000)");
         assertCalculation("-1.02221", "coshIntegral(0.200000)");
         assertCalculation("1.7061", "digamma(6.0000)");
+        assertCalculation("34459425", "doubleFactorial(17)");
         assertCalculation("1.48904", "ellipticE(0.200000)");
         assertCalculation("1.65962", "ellipticK(0.200000)");
         assertCalculation("2.22703e-1", "erf(0.200000)");
         assertCalculation("7.77297e-1", "erfc(0.200000)");
         assertCalculation("2.41591", "erfi(1.20000)");
-        assertCalculation("1.172", "expIntegralE(0.70000,0.30000)");
+        assertCalculation("1.2141", "eulerE(4, 1.90000)");
+        assertCalculation("1.1722", "expIntegralE(0.70000,0.30000)");
         assertCalculation("2.44209", "expIntegralEi(1.20000)");
         assertCalculation("5040", "factorial(7)");
+        assertCalculation("7.3936", "fibonacci(5.00000, 1.20000)");
         assertCalculation("2", "floor(2.9)");
         assertCalculation("2", "floor(29/10)");
         assertCalculation("9e-1", "frac(2.9)");
@@ -246,12 +271,19 @@ public class CalculatorTest
         assertCalculation("5.8861", "gamma(4.0000, 1.0000)");
         assertCalculation("5.0928", "gamma(4.0000, 0, 6.0000)");
         assertCalculation("4.74294943677064514689542753377e1-3.27488916473624576880974867017e1i", "gamma(100.000000000000000000000000000+374.000000000000000000000000000i)");
+        assertCalculation("-5.25676", "gegenbauerC(-1.10000,2.50000)");
+        assertCalculation("-2.60129", "gegenbauerC(-1.10000,-1.30000,2.50000)");
         assertCalculation("1.282427", "glaisher(7)");
+        assertCalculation("1.12151", "harmonicNumber(1.20000)");
+        assertCalculation("1.104112", "harmonicNumber(1.200000,1.300000)");
+        assertCalculation("42142223/12252240", "harmonicNumber(17)");
+        assertCalculation("6301272372663207205033976933/6076911214672415134617600000", "harmonicNumber(13,5)");
+        assertCalculation("3.04424", "hermiteH(1.20000,1.30000)");
         assertCalculation("1.453+1.237i", "hypergeometric0F1(3.456+2.890i,0.1234+4.678i)");
         assertCalculation("2.6328", "hypergeometric0F1Regularized(-3.00000,2.50000)");
         assertCalculation("-7.477+3.738i", "hypergeometric1F1(3.456+2.890i,3.456+2.890i,2.1234+2.678i)");
         assertCalculation("1.2856", "hypergeometric1F1Regularized(0.200000,-3,1.50000)");
-        assertCalculation("-1.478-2.074i", "hypergeometric2F1(9.456+4.890i,3.456+2.890i,1.256+1.390i,0.11234+0.1678i)");
+        assertCalculation("-1.477-2.073i", "hypergeometric2F1(9.456+4.890i,3.456+2.890i,1.256+1.390i,0.11234+0.1678i)");
         assertCalculation("4.8317", "hypergeometric2F1Regularized(0.100000,0.200000,-3,0.800000)");
         assertCalculation("4.99704", "hypergeometricU(1.20000,2,0.200000)");
         assertCalculation("2", "fmod(5, 3)");
@@ -263,13 +295,22 @@ public class CalculatorTest
         assertCalculation("5e-1", "inverseRoot(4.0, 2)");
         assertCalculation("7.07e-1-7.07e-1i", "inverseRoot(-0.707+0.707i, 3)");
         assertCalculation("-5e-1", "inverseRoot(4.0, 2, 1)");
+        assertCalculation("6.28477", "jacobiP(1.20000,1.70000,0.900000,1.90000)");
         assertCalculation("2.685452", "khinchin(7)");
+        assertCalculation("-1.01693", "laguerreL(1.20000,1.90000)");
+        assertCalculation("1.38308", "laguerreL(1.20000,1.70000,1.30000)");
+        assertCalculation("2.26206", "legendreP(1.20000,1.90000)");
+        assertCalculation("-3.36749", "legendreP(1.20000,1.70000,0.900000)");
+        assertCalculation("1.07204", "legendreQ(1.70000,-0.900000)");
+        assertCalculation("4.1358", "legendreQ(1.20000,1.70000,0.900000)");
         assertCalculation("-4.371-3.651i", "logGamma(-1.234+2.345i)");
-        assertCalculation("1.04516", "logIntegral(2.0000)");
+        assertCalculation("1.04516", "logIntegral(2.000000)");
+        assertCalculation("8.80797e-1", "logisticSigmoid(2.00000)");
         assertCalculation("1.23", "n(1.23456, 3)");
         assertCalculation("1.04748", "pochhammer(1.20000,0.700000)");
         assertCalculation("280/81", "pochhammer(1/3,4)");
         assertCalculation("-3.2018", "polygamma(2,0.900000)");
+        assertCalculation("1.79112-2.61823i", "polylog(1.20000,1.30000)");
         assertCalculation("2", "root(8, 3)");
         assertCalculation("2/3", "root(16/81, 4)");
         assertCalculation("7.07e-1+7.07e-1i", "root(-0.707+0.707i, 3)");
@@ -309,8 +350,10 @@ public class CalculatorTest
         assertCalculation("2.1e10", "scale(2.1, 10)");
         assertCalculation("2.5e10+1.5e10i", "scale(2.5+1.5i, 10)");
         assertCalculation("200000/3", "scale(2/3, 5)");
+        assertCalculation("4.54649e-1", "sinc(2.00000)");
         assertCalculation("1.60541", "sinIntegral(2.00000)");
         assertCalculation("2.50157", "sinhIntegral(2.00000)");
+        assertCalculation("4.33712e-1-1.30178e-1i", "sphericalHarmonicY(1.20000,1.50000,0.900000,1.90000)");
         assertCalculation("3", "sqrt(9)");
         assertCalculation("2/3", "sqrt(4/9)");
         assertCalculation("7.07+7.07i", "sqrt(100.i)");
@@ -388,6 +431,11 @@ public class CalculatorTest
         assertCalculationFailure("bernoulli(i)");
         assertCalculationFailure("bernoulli()");
         assertCalculationFailure("bernoulli(1,1)");
+        assertCalculationFailure("bernoulliB(1)");
+        assertCalculationFailure("bernoulliB(1,1.0,1.0)");
+        assertCalculationFailure("bernoulliB(-1,1.0)");
+        assertCalculationFailure("bernoulliB(i,1.0)");
+        assertCalculationFailure("bernoulliB(2/3,1.0)");
         assertCalculationFailure("besselI(1.0)");
         assertCalculationFailure("besselI(1.0,1.0,1.0)");
         assertCalculationFailure("besselJ(1.0)");
@@ -418,6 +466,10 @@ public class CalculatorTest
         assertCalculationFailure("ceil(i)");
         assertCalculationFailure("ceil()");
         assertCalculationFailure("ceil(2, 2)");
+        assertCalculationFailure("chebyshevT(1.0)");
+        assertCalculationFailure("chebyshevT(1.0,1.0,1.0)");
+        assertCalculationFailure("chebyshevU(1.0)");
+        assertCalculationFailure("chebyshevU(1.0,1.0,1.0)");
         assertCalculationFailure("copySign(2i, -3)");
         assertCalculationFailure("copySign(2)");
         assertCalculationFailure("copySign(2, 2, 2)");
@@ -428,6 +480,11 @@ public class CalculatorTest
         assertCalculationFailure("digamma(0)");
         assertCalculationFailure("digamma()");
         assertCalculationFailure("digamma(2,2)");
+        assertCalculationFailure("doubleFactorial(0.5)");
+        assertCalculationFailure("doubleFactorial(2i)");
+        assertCalculationFailure("doubleFactorial(2/3)");
+        assertCalculationFailure("doubleFactorial()");
+        assertCalculationFailure("doubleFactorial(2, 2)");
         assertCalculationFailure("ellipticE()");
         assertCalculationFailure("ellipticE(0.5,0.5)");
         assertCalculationFailure("ellipticK()");
@@ -438,6 +495,11 @@ public class CalculatorTest
         assertCalculationFailure("erfc(0.5,0.5)");
         assertCalculationFailure("erfi()");
         assertCalculationFailure("erfi(0.5,0.5)");
+        assertCalculationFailure("eulerE(1)");
+        assertCalculationFailure("eulerE(1,1.0,1.0");
+        assertCalculationFailure("eulerE(-1,1.0)");
+        assertCalculationFailure("eulerE(i,1.0)");
+        assertCalculationFailure("eulerE(2/3,1.0)");
         assertCalculationFailure("expIntegralE(0.5)");
         assertCalculationFailure("expIntegralE(0.5,0.5,0.5)");
         assertCalculationFailure("expIntegralEi()");
@@ -447,6 +509,8 @@ public class CalculatorTest
         assertCalculationFailure("factorial(2/3)");
         assertCalculationFailure("factorial()");
         assertCalculationFailure("factorial(2, 2)");
+        assertCalculationFailure("fibonacci(1.0)");
+        assertCalculationFailure("fibonacci(1.0,1.0,1.0)");
         assertCalculationFailure("floor(i)");
         assertCalculationFailure("floor()");
         assertCalculationFailure("floor(2, 2)");
@@ -460,12 +524,20 @@ public class CalculatorTest
         assertCalculationFailure("gamma(0)");
         assertCalculationFailure("gamma()");
         assertCalculationFailure("gamma(2, 2, 2, 2)");
+        assertCalculationFailure("gegenbauerC(1.0)");
+        assertCalculationFailure("gegenbauerC(1.0,1.0,1.0,1.0)");
         assertCalculationFailure("glaisher()");
         assertCalculationFailure("glaisher(5, 5)");
         assertCalculationFailure("glaisher(0)");
         assertCalculationFailure("glaisher(-1)");
         assertCalculationFailure("glaisher(0.5)");
         assertCalculationFailure("glaisher(i)");
+        assertCalculationFailure("harmonicNumber()");
+        assertCalculationFailure("harmonicNumber(-1)");
+        assertCalculationFailure("harmonicNumber(-1,1)");
+        assertCalculationFailure("harmonicNumber(1.0,1.0,1.0)");
+        assertCalculationFailure("hermiteH(1.0)");
+        assertCalculationFailure("hermiteH(1.0,1.0,1.0)");
         assertCalculationFailure("hypergeometric0F1(0)");
         assertCalculationFailure("hypergeometric0F1(0,0)");
         assertCalculationFailure("hypergeometric0F1(0,0,0)");
@@ -509,18 +581,28 @@ public class CalculatorTest
         assertCalculationFailure("inverseRoot(2.0, i, 1)");
         assertCalculationFailure("inverseRoot(2.0, i, i)");
         assertCalculationFailure("inverseRoot(2.0, 2, 2, 2)");
+        assertCalculationFailure("jacobiP(1.0,1.0,1.0)");
+        assertCalculationFailure("jacobiP(1.0,1.0,1.0,1.0,1.0)");
         assertCalculationFailure("khinchin()");
         assertCalculationFailure("khinchin(5, 5)");
         assertCalculationFailure("khinchin(0)");
         assertCalculationFailure("khinchin(-1)");
         assertCalculationFailure("khinchin(0.5)");
         assertCalculationFailure("khinchin(i)");
+        assertCalculationFailure("laguerreL(1.0)");
+        assertCalculationFailure("laguerreL(1.0,1.0,1.0,1.0)");
+        assertCalculationFailure("legendreP(1.0)");
+        assertCalculationFailure("legendreP(1.0,1.0,1.0,1.0)");
+        assertCalculationFailure("legendreQ(1.0)");
+        assertCalculationFailure("legendreQ(1.0,1.0,1.0,1.0)");
         assertCalculationFailure("logGamma(0)");
         assertCalculationFailure("logGamma(-1)");
         assertCalculationFailure("logGamma()");
         assertCalculationFailure("logGamma(2,2)");
         assertCalculationFailure("logIntegral()");
         assertCalculationFailure("logIntegral(1.0,1.0)");
+        assertCalculationFailure("logisticSigmoid()");
+        assertCalculationFailure("logisticSigmoid(2.0,2.0)");
         assertCalculationFailure("n(1.23456, i)");
         assertCalculationFailure("n(1.23456, 0.5)");
         assertCalculationFailure("n(1.23456)");
@@ -531,6 +613,8 @@ public class CalculatorTest
         assertCalculationFailure("polygamma(1)");
         assertCalculationFailure("polygamma(-1,1.0)");
         assertCalculationFailure("polygamma(1,1.0,1.0)");
+        assertCalculationFailure("polylog(0.5)");
+        assertCalculationFailure("polylog(0.5,0.5,0.5)");
         assertCalculationFailure("root(2, 2)");
         assertCalculationFailure("root(2)");
         assertCalculationFailure("root(2, i)");
@@ -567,10 +651,14 @@ public class CalculatorTest
         assertCalculationFailure("scale(1.23456, 0.5)");
         assertCalculationFailure("scale(1.23456)");
         assertCalculationFailure("scale(1.23456, 2, 2)");
+        assertCalculationFailure("sinc()");
+        assertCalculationFailure("sinc(1.0,1.0)");
         assertCalculationFailure("sinIntegral()");
         assertCalculationFailure("sinIntegral(1.0,1.0)");
         assertCalculationFailure("sinhIntegral()");
         assertCalculationFailure("sinhIntegral(1.0,1.0)");
+        assertCalculationFailure("sphericalHarmonicY(1.0,1.0,1.0)");
+        assertCalculationFailure("sphericalHarmonicY(1.0,1.0,1.0,1.0,1.0)");
         assertCalculationFailure("sqrt(2)");
         assertCalculationFailure("sqrt()");
         assertCalculationFailure("sqrt(4, 2)");
@@ -724,8 +812,10 @@ public class CalculatorTest
         assertCalculation("-0.258819", "airyAiPrime(0)", "-p", "-i", "6");
         assertCalculation("0.614927", "airyBi(0)", "-p", "-i", "6");
         assertCalculation("0.448288", "airyBiPrime(0)", "-p", "-i", "6");
+        assertCalculation("-7.09216", "bernoulliB(16, 0)", "-i", "6");
         assertCalculation("1.5708", "ellipticE(0)", "-p", "-i", "6");
         assertCalculation("1.5708", "ellipticK(0)", "-p", "-i", "6");
+        assertCalculation("58098.1", "eulerE(15, 0)", "-p", "-i", "6");
     }
 
     private static final String NEWLINE = System.lineSeparator();
