@@ -1,7 +1,7 @@
 /*
  * MIT License
  *
- * Copyright (c) 2002-2023 Mikko Tommila
+ * Copyright (c) 2002-2024 Mikko Tommila
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -27,6 +27,7 @@ import java.io.Serializable;
 import java.io.PushbackReader;
 import java.io.Writer;
 import java.io.IOException;
+import java.util.Comparator;
 import java.util.Formattable;
 import java.util.Formatter;
 import static java.util.FormattableFlags.*;
@@ -43,7 +44,7 @@ import static java.util.FormattableFlags.*;
  * @see Apfloat
  * @see ApcomplexMath
  *
- * @version 1.10.1
+ * @version 1.13.0
  * @author Mikko Tommila
  */
 
@@ -92,6 +93,41 @@ public class Apcomplex
 
     public static final long DEFAULT = 0x8000000000000000L;
 
+    /**
+     * Comparator for ordering by real part, and in case of a tie, by imaginary
+     * part.
+     */
+
+    public static final Comparator<Apcomplex> REAL_IMAG_ORDER = (z, w) ->
+    {
+        int result = z.real().compareTo(w.real());
+        if (result == 0)
+        {
+            result = z.imag().compareTo(w.imag());
+        }
+        return result;
+    };
+
+    /**
+     * Comparator for ordering by real part, and in case of a tie, by the
+     * absolute value of the imaginary part. If a tie persists, order by
+     * imaginary part.
+     */
+
+    public static final Comparator<Apcomplex> REAL_ABS_IMAG_ORDER = (z, w) ->
+    {
+        int result = z.real().compareTo(w.real());
+        if (result == 0)
+        {
+            result = ApfloatMath.abs(z.imag()).compareTo(ApfloatMath.abs(w.imag()));
+        }
+        if (result == 0)
+        {
+            result = Integer.compare(z.imag().signum(), w.imag().signum());
+        }
+        return result;
+    };
+
     /**
      * Extra precision that is added in various apfloat internal
      * operations to avoid round-off errors.
@@ -378,6 +414,20 @@ public class Apcomplex
         return Math.max(real().size(), imag().size());
     }
 
+    /**
+     * Returns if this number is zero.
+     *
+     * @return If this number is zero.
+     *
+     * @since 1.13.0
+     */
+
+    public boolean isZero()
+        throws ApfloatRuntimeException
+    {
+        return real().signum() == 0 && imag().signum() == 0;
+    }
+
     /**
      * Returns if this number has an integer value. Note that this does not
      * necessarily mean that this object is an instance of {@link Apint}.
@@ -468,9 +518,9 @@ public class Apcomplex
     public Apcomplex divide(Apcomplex z)
         throws ArithmeticException, ApfloatRuntimeException
     {
-        if (z.real().signum() == 0 && z.imag().signum() == 0)
+        if (z.isZero())
         {
-            throw new ArithmeticException(real().signum() == 0 && imag().signum() == 0 ? "Zero divided by zero" : "Division by zero");
+            throw new ArithmeticException(isZero() ? "Zero divided by zero" : "Division by zero");
         }
 
         Apfloat tmpReal,
@@ -630,7 +680,7 @@ public class Apcomplex
      *
      * @return The numeric value represented by this object after conversion to type <code>byte</code>.
      *
-     * @throws ArithmeticException If the value of <code>this</code> will not exactly fit in a <code>byte</code>.
+     * @throws ArithmeticException If the value of <code>this</code> will not exactly fit in a <code>byte</code> or has a nonzero fractional part.
      *
      * @since  1.9.0
      */
@@ -652,7 +702,7 @@ public class Apcomplex
      * of the <code>short</code> type, then an <code>ArithmeticException</code>
      * is thrown.
      *
-     * @return The numeric value represented by this object after conversion to type <code>short</code>.
+     * @return The numeric value represented by this object after conversion to type <code>short</code> or has a nonzero fractional part.
      *
      * @throws ArithmeticException If the value of <code>this</code> will not exactly fit in a <code>short</code>.
      *
@@ -678,7 +728,7 @@ public class Apcomplex
      *
      * @return The numeric value represented by this object after conversion to type <code>int</code>.
      *
-     * @throws ArithmeticException If the value of <code>this</code> will not exactly fit in an <code>int</code>.
+     * @throws ArithmeticException If the value of <code>this</code> will not exactly fit in an <code>int</code> or has a nonzero fractional part.
      *
      * @since  1.9.0
      */
@@ -702,7 +752,7 @@ public class Apcomplex
      *
      * @return The numeric value represented by this object after conversion to type <code>long</code>.
      *
-     * @throws ArithmeticException If the value of <code>this</code> will not exactly fit in a <code>long</code>.
+     * @throws ArithmeticException If the value of <code>this</code> will not exactly fit in a <code>long</code> or has a nonzero fractional part.
      *
      * @since  1.9.0
      */
@@ -737,8 +787,7 @@ public class Apcomplex
     public long equalDigits(Apcomplex z)
         throws ApfloatRuntimeException
     {
-        if (real().signum() == 0 && imag().signum() == 0 &&
-            z.real().signum() == 0 && z.imag().signum() == 0)
+        if (isZero() && z.isZero())
         {
             // Both are zero
             return Apfloat.INFINITE;
