@@ -41,7 +41,7 @@ import static org.apfloat.spi.RadixConstants.*;
 /**
  * Various utility methods related to apfloats.
  *
- * @version 1.13.0
+ * @version 1.14.0
  * @author Mikko Tommila
  */
 
@@ -489,6 +489,13 @@ class ApfloatHelper
         return LONG_PRECISION[radix];
     }
 
+    // To handle accumulating round-off errors better in slow functions
+    public static long getSmallExtraPrecision(int radix)
+    {
+        assert (radix > 0);
+        return Math.min(3, (long) Math.ceil(5 / Math.log(radix)));
+    }
+
     // Returns x with precision at most as specified
     public static Apfloat limitPrecision(Apfloat x, long precision)
         throws ApfloatRuntimeException
@@ -519,6 +526,10 @@ class ApfloatHelper
     public static long reducePrecision(long precision, long extraPrecision)
         throws ApfloatRuntimeException
     {
+        if (precision == Apfloat.INFINITE)
+        {
+            return precision;
+        }
         precision = precision - extraPrecision;
         if (precision <= 0)
         {
@@ -655,7 +666,7 @@ class ApfloatHelper
         Apint zRounded = RoundingHelper.roundToInteger(z.real(), RoundingMode.HALF_EVEN).truncate();
         if (zRounded.signum() < 0)
         {
-            long digitLoss = -z.subtract(zRounded).scale();
+            long digitLoss = Math.min(precision, -z.subtract(zRounded).scale());
             if (digitLoss > 0)
             {
                 precision = Util.ifFinite(precision, precision + digitLoss);
