@@ -27,11 +27,13 @@ import java.util.Iterator;
 
 import org.apfloat.spi.Util;
 
+import static org.apfloat.ApcomplexMath.isNonPositiveInteger;
+
 /**
  * Helper class for the Hurwitz zeta function.
  *
  * @since 1.11.0
- * @version 1.13.0
+ * @version 1.14.0
  * @author Mikko Tommila
  */
 
@@ -53,21 +55,39 @@ class HurwitzZetaHelper
             Apint two = new Apint(2, radix);
             return new Aprational(one, two);
         }
-        long precision = Math.min(s.precision(),  a.precision());
-        if (a.isInteger() && a.real().signum() <= 0)
+        Apcomplex sOrig = s;
+        long targetPrecision = Math.min(s.precision(),  a.precision()),
+             precision = ApfloatHelper.extendPrecision(targetPrecision);
+        s = ApfloatHelper.ensurePrecision(s, precision);
+        a = ApfloatHelper.ensurePrecision(a, precision);
+        if (isNonPositiveInteger(s))
+        {
+            // Handle cases where the result might be genuinely zero
+            long n1 = ApfloatHelper.longValueExact(one.subtract(s.real().truncate()));
+            return bernoulliB(n1, a).divide(new Apfloat(n1, targetPrecision, radix)).negate();
+        }
+        if (isNonPositiveInteger(a))
         {
             if (s.real().signum() < 0 || s.isZero())
             {
                 // Use recurrence formula: zeta(s, a) = a^-s + zeta(s, a + 1)
-                Apcomplex t = Apcomplex.ZERO;
+                Apcomplex t = Apcomplex.ZERO,
+                          sn = s.negate();
                 long i = ApfloatHelper.longValueExact(a.real().truncate());
                 while (i++ <= 0)
                 {
-                    t = t.add(ApcomplexMath.pow(a, s.negate()));
+                    t = t.add(ApcomplexMath.pow(a, sn));
                     a = a.add(one);
                 }
-                a = a.precision(precision);
-                return t.add(zeta(s, a).precision(precision));  // Precision is not correct as S, I and T cancel out each other
+                t = ApfloatHelper.reducePrecision(t);
+                s = sOrig;
+                a = a.precision(targetPrecision);
+                Apcomplex z = zeta(s, a);
+                if (t.isZero())
+                {
+                    return z;
+                }
+                return t.add(ApfloatHelper.ensurePrecision(z, precision));
             }
 
             throw new ArithmeticException("Zeta of second argument nonpositive integer");
@@ -82,15 +102,28 @@ class HurwitzZetaHelper
         // Far in the critical strip N should be larger than M for better efficiency
         // Note that the search is for the absolute size of the error term, not the relative error (relative to the value of the zeta function being evaluated)
         // Thus we would first need some guess for the scale of the value of the Hurwitz zeta function, to have a goal for the size of the error term
-        long zetaScale = Math.min(0, zetaScale(s.precision(doublePrecision), a.precision(doublePrecision)));
-        Apint N = binarySearch(ApfloatHelper.limitPrecision(s, doublePrecision), ApfloatHelper.limitPrecision(a, doublePrecision), precision, -Util.ifFinite(-zetaScale, precision - zetaScale)),
-              M = N;
-        s = ApfloatHelper.extendPrecision(s);
-        a = ApfloatHelper.extendPrecision(a);
-        Apcomplex I = I(s, a, N),
-                  S = S(s, a, N.longValueExact()),
-                  T = T(s, a, N, M.longValueExact());
-        return ApfloatHelper.reducePrecision(S.add(I).add(T));
+        long zetaScale = Math.min(0, zetaScale(s.precision(doublePrecision), a.precision(doublePrecision))),
+             targetScale = -Util.ifFinite(-zetaScale, targetPrecision - zetaScale),
+             precisionLoss;
+        Apcomplex result;
+        do
+        {
+            Apint N = binarySearch(s, a, targetPrecision, targetScale), // s could be a nonpositive near-integer so easier not to round it to avoid getting a zero from the Pochammer symbol
+                  M = N;
+            Apcomplex I = I(s, a, N),
+                      S = S(s, a, N.longValueExact()),
+                      T = T(s, a, N, M.longValueExact());
+            result = S.add(I).add(T);
+            precisionLoss = (result.isZero() ? precision : targetPrecision - result.precision());   // Assumed that the result can't be exactly zero because those are handled by the polynomial case above (the real zeros)
+            if (precisionLoss > 0)
+            {
+                precision = Util.ifFinite(precision, precision + precisionLoss);
+                targetScale = -Util.ifFinite(-targetScale, -targetScale + precisionLoss);
+                s = ApfloatHelper.ensurePrecision(s, precision);
+                a = ApfloatHelper.ensurePrecision(a, precision);
+            }
+        } while (precisionLoss > 0);
+        return ApfloatHelper.limitPrecision(result, targetPrecision);
     }
 
     private static long zetaScale(Apcomplex s, Apcomplex a)
@@ -235,4 +268,33 @@ class HurwitzZetaHelper
         // Increase the precision to avoid loss of precision exception
         return ApfloatHelper.extendPrecision(x, Math.max(0, x.scale()));
     }
+
+    // Bernoulli polynomial, calculated as a polynomial
+    // z assumed to be of extended precision already
+    private static Apcomplex bernoulliB(long n, Apcomplex z)
+    {
+        assert (n > 0);
+        long precision = z.precision();
+        int radix = z.radix();
+        if (z.isZero())
+        {
+            return AprationalMath.bernoulli(n, radix);
+        }
+        Apcomplex sum = Apcomplex.ZEROS[radix],
+                  numerator = new Apfloat(1, precision, radix),
+                  denominator = numerator;
+        Iterator<Aprational> bernoullis = AprationalMath.bernoullis(n, radix);
+        for (long k = 0; k <= n; k++)
+        {
+            Aprational b = bernoullis.next();
+            sum = sum.add(b.multiply(numerator).divide(denominator));
+            if (k < n)
+            {
+                numerator = numerator.multiply(new Apint(n - k, radix));
+                denominator = denominator.multiply(new Apint(k + 1, radix)).multiply(z);
+            }
+        }
+        sum = sum.multiply(ApcomplexMath.pow(z, n));
+        return ApfloatHelper.reducePrecision(sum);
+    }
 }
