@@ -36,6 +36,7 @@ import static java.util.Comparator.comparing;
 import static org.apfloat.ApcomplexMath.abs;
 import static org.apfloat.ApcomplexMath.exp;
 import static org.apfloat.ApcomplexMath.gamma;
+import static org.apfloat.ApcomplexMath.isNonPositiveInteger;
 import static org.apfloat.ApcomplexMath.pow;
 import static org.apfloat.ApcomplexMath.sin;
 import static org.apfloat.ApcomplexMath.sqrt;
@@ -46,7 +47,7 @@ import static org.apfloat.ApfloatMath.scale;
  * Helper class for hypergeometric functions.
  *
  * @since 1.11.0
- * @version 1.13.0
+ * @version 1.14.0
  * @author Mikko Tommila
  */
 
@@ -110,14 +111,17 @@ class HypergeometricHelper
                 digitLoss = workingPrecision;
                 workingPrecision = Util.ifFinite(workingPrecision, workingPrecision + digitLoss);
                 Apfloat offset = offset(-digitLoss);
-                a = new Apcomplex(a.real().precision(Apfloat.INFINITE).add(offset), a.imag());
+                if (!b.equals(offset))  // It might be that b is exactly the same as the offset so a - b is not integer after all (but would be if we did add the offset), we just need to increase the precisions
+                {
+                    a = new Apcomplex(a.real().precision(Apfloat.INFINITE).add(offset), a.imag());
+                }
                 b = new Apcomplex(adjustOffset(b.real(), offset), b.imag());
                 ensurePrecisions();
             }
             else
             {
                 Apint abRounded = RoundingHelper.roundToInteger(ab.real(), RoundingMode.HALF_EVEN).truncate();
-                digitLoss = -ab.subtract(abRounded).scale();
+                digitLoss = Math.min(workingPrecision, -ab.subtract(abRounded).scale());
                 if (digitLoss > 0)
                 {
                     workingPrecision = Util.ifFinite(workingPrecision, workingPrecision + digitLoss);
@@ -137,6 +141,9 @@ class HypergeometricHelper
             long digitLoss;
             if (cab.isInteger())
             {
+                Apcomplex aOrig = a,
+                          bOrig = b,
+                          cOrig = c;
                 // Adjust the one which has largest magnitude in real part
                 swapLargerAB();
                 digitLoss = workingPrecision;
@@ -154,11 +161,20 @@ class HypergeometricHelper
                 }
                 b = new Apcomplex(adjustOffset(b.real(), offset), b.imag());
                 ensurePrecisions();
+                if (c.subtract(a).subtract(b).isInteger())
+                {
+                    // It could be that a+b happened to be equal to the offset, to suitable precision, so we don't need to adjust by offset after all, we just need to increase the precision
+                    a = aOrig;
+                    b = bOrig;
+                    c = cOrig;
+                    ensurePrecisions();
+                    assert (!c.subtract(a).subtract(b).isInteger());
+                }
             }
             else
             {
                 Apint cabRounded = RoundingHelper.roundToInteger(cab.real(), RoundingMode.HALF_EVEN).truncate();
-                digitLoss = -cab.subtract(cabRounded).scale();
+                digitLoss = Math.min(workingPrecision, -cab.subtract(cabRounded).scale());
                 if (digitLoss > 0)
                 {
                     workingPrecision = Util.ifFinite(workingPrecision, workingPrecision + digitLoss);
@@ -186,7 +202,7 @@ class HypergeometricHelper
         {
             Apcomplex term1,
                       term2;
-            if (g1.isInteger() && g1.real().signum() <= 0 || g2.isInteger() && g2.real().signum() <= 0)
+            if (isNonPositiveInteger(g1) || isNonPositiveInteger(g2))
             {
                 term1 = zero;   // Division by infinity
             }
@@ -194,7 +210,7 @@ class HypergeometricHelper
             {
                 term1 = pow(base1, exp1).divide(gamma(g1).multiply(gamma(g2)).multiply(gamma(c1))).multiply(evaluate(a1, b1, c1, z));
             }
-            if (g3.isInteger() && g3.real().signum() <= 0 || g4.isInteger() && g4.real().signum() <= 0)
+            if (isNonPositiveInteger(g3) || isNonPositiveInteger(g4))
             {
                 term2 = zero;   // Division by infinity
             }
@@ -276,7 +292,7 @@ class HypergeometricHelper
                           z1 = one.subtract(z),
                           s = c.subtract(a),
                           t = c.subtract(b);
-                if (s.isInteger() && s.real().signum() <= 0 && (!t.isInteger() || t.real().signum() > 0 || s.real().compareTo(t.real()) >= 0))
+                if (isNonPositiveInteger(s) && (!isNonPositiveInteger(t) || s.real().compareTo(t.real()) >= 0))
                 {
                     return ApcomplexMath.pow(z1, b.negate()).multiply(helper.evaluate(s, b, c, z(z)));
                 }
@@ -410,12 +426,13 @@ class HypergeometricHelper
 
     private HypergeometricHelper(Apcomplex[] a, Apcomplex[] b, Apcomplex z)
     {
-        this.a = a;
-        this.b = b;
-        this.z = z;
-        this.targetPrecision = precision(a, b, z);
-        this.workingPrecision = targetPrecision;
         this.radix = z.radix();
+        this.extraPrecision = ApfloatHelper.getSmallExtraPrecision(radix);
+        this.targetPrecision = ApfloatHelper.extendPrecision(precision(a, b, z), extraPrecision);
+        this.workingPrecision = targetPrecision;
+        this.a = Arrays.stream(a).map(c -> ApfloatHelper.extendPrecision(c, extraPrecision)).toArray(Apcomplex[]::new);
+        this.b = Arrays.stream(b).map(c -> ApfloatHelper.extendPrecision(c, extraPrecision)).toArray(Apcomplex[]::new);
+        this.z = ensurePrecision(z);
         this.one = Apint.ONES[radix];
         this.zero = Apint.ZEROS[radix];
     }
@@ -439,7 +456,8 @@ class HypergeometricHelper
 
     public static Apcomplex hypergeometricPFQ(Apcomplex[] a, Apcomplex[] b, Apcomplex z)
     {
-        return new HypergeometricHelper(a, b, z).hypergeometricPFQ();
+        HypergeometricHelper helper = new HypergeometricHelper(a, b, z);
+        return helper.result(helper.hypergeometricPFQ());
     }
 
     /**
@@ -463,7 +481,8 @@ class HypergeometricHelper
 
     public static Apcomplex hypergeometricPFQRegularized(Apcomplex[] a, Apcomplex[] b, Apcomplex z)
     {
-        return new HypergeometricHelper(a, b, z).hypergeometricPFQRegularized();
+        HypergeometricHelper helper = new HypergeometricHelper(a, b, z);
+        return helper.result(helper.hypergeometricPFQRegularized());
     }
 
     private Apcomplex hypergeometricPFQRegularized()
@@ -475,7 +494,7 @@ class HypergeometricHelper
         for (int i = 0; i < b.length; i++)
         {
             Apfloat br = b[i].real().negate();
-            if (b[i].isInteger() && br.signum() >= 0)
+            if (isNonPositiveInteger(b[i]))
             {
                 if (n == null)
                 {
@@ -528,15 +547,17 @@ class HypergeometricHelper
      * @param a The first argument.
      * @param b The second argument.
      * @param z The third argument.
+     * @param fastOnly Only attempt relatively fast algorithms and return null if not applicable
      *
      * @return <i>U(a, b, z)</i>
      *
      * @since 1.13.0
      */
 
-    public static Apcomplex hypergeometricU(Apcomplex a, Apcomplex b, Apcomplex z)
+    public static Apcomplex hypergeometricU(Apcomplex a, Apcomplex b, Apcomplex z, boolean fastOnly)
     {
-        return new HypergeometricHelper(new Apcomplex[] { a }, new Apcomplex[] { b }, z).hypergeometricU();
+        HypergeometricHelper helper = new HypergeometricHelper(new Apcomplex[] { a }, new Apcomplex[] { b }, z);
+        return helper.result(helper.hypergeometricU(fastOnly));
     }
 
     // In the general case (p = q + 1) this works only for |z| < 1, and in general, may converge slowly for very large |z|
@@ -592,11 +613,38 @@ class HypergeometricHelper
         if (abs(z).doubleValue() > targetPrecision * Math.log(radix))
         {
             // Evaluate with 1F1
-            Apcomplex sqrtZ = sqrt(z);
+            // https://functions.wolfram.com/HypergeometricFunctions/Hypergeometric0F1/27/01/
             Apint two = new Apint(2, radix),
                   four = new Apint(4, radix);
             Aprational half = new Aprational(one, two);
-            Apcomplex result = exp(two.negate().multiply(sqrtZ)).multiply(hypergeometric1F1(b.subtract(half), two.multiply(b).subtract(one), four.multiply(sqrtZ)));
+            Apcomplex b12 = ensurePrecision(b.subtract(half));
+            if (isNonPositiveInteger(b12))
+            {
+                // This transformation wouldn't work correctly if 0F1 is not polynomial, but 1F1 becomes polynomial (b12 is nonpositive integer)
+                // Note that if b is not a nonpositive integer (in which case 0F1 would also throw exception) then 2b-1 is not a nonpositive integer either so b21 is not a problem like b12
+                long digitLoss = workingPrecision;
+                workingPrecision = Util.ifFinite(workingPrecision, workingPrecision + digitLoss);
+                Apfloat offset = offset(-digitLoss);
+                b = new Apcomplex(b.real().precision(Apfloat.INFINITE).add(offset), b.imag());
+                b = ensurePrecision(b);
+                z = ensurePrecision(z);
+                b12 = ensurePrecision(b.subtract(half));
+            }
+            Apcomplex b21 = ensurePrecision(two.multiply(b).subtract(one)),
+                      result;
+            if (z.real().signum() >= 0)
+            {
+                // Use the formula for Bessel I and Bessel I as 1F1
+                Apcomplex sqrtZ = sqrt(z);
+                result = exp(two.negate().multiply(sqrtZ)).multiply(hypergeometric1F1(b12, b21, four.multiply(sqrtZ)));
+            }
+            else
+            {
+                // Use the formula for Bessel J and Bessel J as 1F1
+                Apcomplex i = new Apcomplex(zero, one),
+                          sqrtZ = sqrt(z.negate());
+                result = exp(two.negate().multiply(i).multiply(sqrtZ)).multiply(hypergeometric1F1(b12, b21, four.multiply(i).multiply(sqrtZ)));
+            }
             return ApfloatHelper.limitPrecision(result, targetPrecision);
         }
 
@@ -612,9 +660,10 @@ class HypergeometricHelper
             try
             {
                 // Evaluate with U*
+                // Note: this transformation works correctly if 1F1 is not polynomial but U* becomes polynomial (a or a-b+1 is nonpositive integer, or b-a or 1-a is nonpositive integer)
                 Apcomplex ba = ensurePrecision(b.subtract(a));
                 Apcomplex result = zero;
-                if (!ba.isInteger() || ba.real().signum() > 0)
+                if (!isNonPositiveInteger(ba))
                 {
                     result = pow(z.negate(), a.negate()).divide(gamma(ensureGammaPrecision(ba))).multiply(hypergeometricUStar(a, b, z));
                 }
@@ -632,6 +681,10 @@ class HypergeometricHelper
 
     private Apcomplex hypergeometric1F1series(Apcomplex a, Apcomplex b, Apcomplex z)
     {
+        if (a.equals(b) && !isNonPositiveInteger(a))
+        {
+            return ApcomplexMath.exp(z);
+        }
         Apcomplex factor = one;
         if (z.real().signum() < 0)
         {
@@ -653,7 +706,7 @@ class HypergeometricHelper
         return result;
     }
 
-    private Apcomplex hypergeometricU()
+    private Apcomplex hypergeometricU(boolean fastOnly)
         throws ArithmeticException, ApfloatRuntimeException
     {
         if (abs(z).doubleValue() > targetPrecision * Math.log(radix))
@@ -663,11 +716,23 @@ class HypergeometricHelper
                 // Evaluate with U*
                 Apcomplex result = pow(z, a[0].negate()).multiply(hypergeometricUStar(a[0], b[0], z));
                 return ApfloatHelper.limitPrecision(result, targetPrecision);
-            } catch (NotConvergingException nce)
+            }
+            catch (NotConvergingException nce)
             {
                 // Ignore and retry with the (possibly very slow) direct evaluation of the series
+                if (fastOnly)
+                {
+                    // Too slow, try another algorithm
+                    return null;
+                }
             }
         }
+        if (fastOnly && (Stream.concat(Arrays.stream(a), Arrays.stream(b)).map(Apcomplex::real).reduce(ApfloatMath::min).get().doubleValue() < -100.0 * targetPrecision ||  // Check minimum number of evaluation terms
+                         z.scale() > 5.0 / Math.log(radix)))    // Check convergence speed
+        {
+            // Too slow, try another algorithm
+            return null;
+        }
 
         // Evaluate two 1F1 functions, this often results in cancellation of significant digits so we may retry with higher precision
         Apcomplex result;
@@ -694,7 +759,7 @@ class HypergeometricHelper
             else
             {
                 Apint bRounded = RoundingHelper.roundToInteger(b.real(), RoundingMode.HALF_EVEN).truncate();
-                long digitLoss = -b.subtract(bRounded).scale();
+                long digitLoss = Math.min(workingPrecision, -b.subtract(bRounded).scale());
                 if (digitLoss > 0)
                 {
                     workingPrecision = Util.ifFinite(workingPrecision, workingPrecision + digitLoss);
@@ -706,12 +771,12 @@ class HypergeometricHelper
 
             Apcomplex ab1 = ensureGammaPrecision(a.subtract(b).add(one));
             result = zero;
-            if (!ab1.isInteger() || ab1.real().signum() > 0)
+            if (!isNonPositiveInteger(ab1))
             {
                 Apcomplex b1n = ensureGammaPrecision(one.subtract(b));
                 result = gamma(b1n).divide(gamma(ab1)).multiply(hypergeometric1F1series(a, b, z));
             }
-            if (!a.isInteger() || a.real().signum() > 0)
+            if (!isNonPositiveInteger(a))
             {
                 Apint two = new Apint(2, radix);
                 Apcomplex b1 = ensureGammaPrecision(b.subtract(one)),
@@ -720,7 +785,7 @@ class HypergeometricHelper
                 a = ensureGammaPrecision(a);
                 result = result.add(gamma(b1).divide(gamma(a)).multiply(pow(z, b1n)).multiply(hypergeometric1F1series(ab1, b2, z)));
             }
-            precisionLoss = targetPrecision - result.precision();
+            precisionLoss = (result.isZero() ? workingPrecision : targetPrecision - result.precision());
             workingPrecision = Util.ifFinite(workingPrecision, workingPrecision + precisionLoss);
         } while (precisionLoss > 0);
         return ApfloatHelper.limitPrecision(result, targetPrecision);
@@ -748,7 +813,7 @@ class HypergeometricHelper
             }
             Apcomplex s = c.subtract(a),
                       t = c.subtract(b);
-            if (s.isInteger() && s.real().signum() <= 0 || t.isInteger() && t.real().signum() <= 0)
+            if (isNonPositiveInteger(s) || isNonPositiveInteger(t))
             {
                 return zero;
             }
@@ -848,14 +913,20 @@ class HypergeometricHelper
             Apint i = zero;
             Apcomplex numerator = one,
                       denominator = one,
-                      o,
+                      o = null,
                       t = null;
+            boolean minIterations;
 
             extraPrecision = precisionLoss;
             s = one;
 
             do
             {
+                minIterations = i.compareTo(minN) <= 0;
+                if (divergentSeries && !minIterations)
+                {
+                    checkDivergence(o, t);
+                }
                 i = i.add(one);
                 for (int j = 0; j < a.length; j++)
                 {
@@ -877,7 +948,7 @@ class HypergeometricHelper
                 t = numerator.divide(denominator);
                 s = s.add(t);
                 maxSScale = Math.max(maxSScale, s.scale());
-            } while (i.compareTo(minN) <= 0 || divergentSeries && checkDivergence(o, t) || s.isZero() || s.scale() - t.scale() <= workingPrecision);  // Subtraction might overflow
+            } while (minIterations || s.isZero() || s.scale() - t.scale() <= workingPrecision);  // Subtraction might overflow
 
             precisionLoss = (s.isZero() ? extendedPrecision : maxSScale - s.scale()); // Loss due to scale of s reduced from its peak (loss off most significant digits)
             if (workingPrecision - s.precision() > 1)  // Often the precision is reduced by 1
@@ -895,14 +966,13 @@ class HypergeometricHelper
         return s;
     }
 
-    private boolean checkDivergence(Apcomplex old, Apcomplex term)
+    private void checkDivergence(Apcomplex old, Apcomplex term)
     {
         // Check if the divergent series reached the smallest term already, even though the required precision was not reached
         if (old != null && abs(old).compareTo(abs(term)) < 0)
         {
             throw new NotConvergingException();
         }
-        return false;
     }
 
     // See: https://def.fe.up.pt/pipermail/maxima-discuss/2006.txt "Methods for numerically difficult cases of 2F1(a,b;c|z)", alternative algorithm by Bill Gosper
@@ -987,7 +1057,13 @@ class HypergeometricHelper
         return ApfloatHelper.ensureGammaPrecision(z, workingPrecision);
     }
 
+    private Apcomplex result(Apcomplex z)
+    {
+        return (z == null ? z : ApfloatHelper.reducePrecision(z, extraPrecision));
+    }
+
     private long targetPrecision,
+                 extraPrecision,
                  workingPrecision;
     private int radix;
     private Apcomplex[] a,
