@@ -1,7 +1,7 @@
 /*
  * MIT License
  *
- * Copyright (c) 2002-2021 Mikko Tommila
+ * Copyright (c) 2002-2023 Mikko Tommila
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -58,7 +58,7 @@ import static org.apfloat.internal.RawtypeRadixConstants.*;
  * This implementation doesn't necessarily store any extra digits for added
  * precision, so the last digit of any operation may be inaccurate.
  *
- * @version 1.9.1
+ * @version 1.11.0
  * @author Mikko Tommila
  */
 
@@ -99,7 +99,7 @@ public class RawtypeApfloatImpl
      * @param radix The radix in which the number is created.
      * @param isInteger Specifies if the number to be parsed from the string is to be treated as an integer or not.
      *
-     * @exception java.lang.NumberFormatException If the number is not valid.
+     * @exception NumberFormatException If the number is not valid.
      */
 
     public RawtypeApfloatImpl(String value, long precision, int radix, boolean isInteger)
@@ -344,7 +344,7 @@ public class RawtypeApfloatImpl
      * @param precision The precision of the number (in digits of the radix).
      * @param radix The radix in which the number is created.
      *
-     * @exception java.lang.NumberFormatException If the number is not valid.
+     * @exception NumberFormatException If the number is not valid.
      */
 
     public RawtypeApfloatImpl(long value, long precision, int radix)
@@ -434,7 +434,7 @@ public class RawtypeApfloatImpl
      * @param precision The precision of the number (in digits of the radix).
      * @param radix The radix in which the number is created.
      *
-     * @exception java.lang.NumberFormatException If the number is not valid.
+     * @exception NumberFormatException If the number is not valid.
      */
 
     public RawtypeApfloatImpl(double value, long precision, int radix)
@@ -578,8 +578,8 @@ public class RawtypeApfloatImpl
      * @param radix The radix in which the number is created.
      * @param isInteger Specifies if the number to be parsed from the stream is to be treated as an integer or not.
      *
-     * @exception java.io.IOException If an I/O error occurs accessing the stream.
-     * @exception java.lang.NumberFormatException If the number is not valid.
+     * @exception IOException If an I/O error occurs accessing the stream.
+     * @exception NumberFormatException If the number is not valid.
      */
 
     public RawtypeApfloatImpl(PushbackReader in, long precision, int radix, boolean isInteger)
@@ -674,7 +674,7 @@ public class RawtypeApfloatImpl
                         if (actualSize == initialSize)
                         {
                             // Initial memory block size exceeded; prepare to allocate anything
-                            DataStorage dataStorage = createDataStorage(Long.MAX_VALUE / sizeof(rawtype));
+                            DataStorage dataStorage = createDataStorage(Long.MAX_VALUE / RawType.BYTES);
                             dataStorage.copyFrom(this.dataStorage, actualSize);
                             this.dataStorage = dataStorage;
                         }
@@ -2424,7 +2424,7 @@ public class RawtypeApfloatImpl
         }
         else
         {
-            return (precision + BASE_DIGITS[this.radix] - mswDigits - 1) / BASE_DIGITS[this.radix] + 1;
+            return Long.divideUnsigned(precision + BASE_DIGITS[this.radix] - mswDigits - 1, BASE_DIGITS[this.radix]) + 1;
         }
     }
 
@@ -2454,14 +2454,14 @@ public class RawtypeApfloatImpl
     {
         ApfloatContext ctx = ApfloatContext.getContext();
         DataStorageBuilder dataStorageBuilder = ctx.getBuilderFactory().getDataStorageBuilder();
-        return dataStorageBuilder.createDataStorage(size * sizeof(rawtype));
+        return dataStorageBuilder.createDataStorage(size * RawType.BYTES);
     }
 
     // Gets I/O block size in rawtypes
     private static int getBlockSize()
     {
         ApfloatContext ctx = ApfloatContext.getContext();
-        return ctx.getBlockSize() / sizeof(rawtype);
+        return ctx.getBlockSize() / RawType.BYTES;
     }
 
     private static final DataStorage.Iterator ZERO_ITERATOR =
