@@ -1,7 +1,7 @@
 /*
  * MIT License
  *
- * Copyright (c) 2002-2021 Mikko Tommila
+ * Copyright (c) 2002-2023 Mikko Tommila
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -50,7 +50,7 @@ public class RawtypeDataStorageBuilder
     @Override
     protected long getMaxCachedSize()
     {
-        return (long) sizeof(rawtype) * Integer.MAX_VALUE;
+        return (long) RawType.BYTES * Integer.MAX_VALUE;
     }
 
     @Override
