@@ -1,7 +1,7 @@
 /*
  * MIT License
  *
- * Copyright (c) 2002-2021 Mikko Tommila
+ * Copyright (c) 2002-2023 Mikko Tommila
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -86,7 +86,7 @@ public class RawtypeMediumConvolutionStrategy
 
         ApfloatContext ctx = ApfloatContext.getContext();
         DataStorageBuilder dataStorageBuilder = ctx.getBuilderFactory().getDataStorageBuilder();
-        DataStorage resultStorage = dataStorageBuilder.createDataStorage(size * sizeof(rawtype));
+        DataStorage resultStorage = dataStorageBuilder.createDataStorage(size * RawType.BYTES);
         resultStorage.setSize(size);
 
         DataStorage.Iterator src = longStorage.iterator(DataStorage.READ, longSize, 0),
