@@ -1,7 +1,7 @@
 /*
  * MIT License
  *
- * Copyright (c) 2002-2021 Mikko Tommila
+ * Copyright (c) 2002-2023 Mikko Tommila
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -69,7 +69,7 @@ public class RawtypeBuilderFactoryTest
 
         assertEquals("getElementType()", RawType.TYPE, builderFactory.getElementType());
         assertEquals("getElementArrayType()", rawtype[].class, builderFactory.getElementArrayType());
-        assertEquals("getElementSize()", sizeof(rawtype), builderFactory.getElementSize());
+        assertEquals("getElementSize()", RawType.BYTES, builderFactory.getElementSize());
 
         Class<?>[] types = { Integer.TYPE, Long.TYPE, Float.TYPE, Double.TYPE };
         for (Class<?> type : types)
